=======
History
=======

0.1.5 (2018-12-14)
------------------

* Changes in pycountry module which needed some changes also to Verifone's country and currency methods.

0.1.4 (2018-11-12)
------------------

* Fixed length of extra data fields. External id can be 255 characters and note 36 characters.

0.1.3 (2018-10-26)
------------------

* Remove s-t-1-40_shop-order__phase from signature verification.

0.1.2 (2018-09-12)
------------------

* Changes in generate_payment_data feature.


0.1.1 (2018-09-06)
------------------

* Added post urls for hosted pages.


0.1.0 (2018-08-31)
------------------

* First release on PyPI.
